
# Slot: domain_of


the class(es) that reference the slot in a "slots" or "slot_usage" context

URI: [linkml:domain_of](https://w3id.org/linkml/domain_of)


## Domain and Range

[SlotDefinition](SlotDefinition.md) &#8594;  <sub>0..\*</sub> [ClassDefinition](ClassDefinition.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)
